#確率変数の標準化
print('【確率変数の標準化】')
#準備
import numpy as np
from scipy.stats import binom
import matplotlib.pyplot as plt

#コインを投げる回数の設定
ntrial=10

#表の枚数Xの確率変数
x = np.arange(ntrial+1)
print('元の確率変数とその分布')
print('表の枚数X：',end='') 
for i in x:
   print(x[i],end='     ') 
print()

#確率分布
phead=0.5   #コインの表の出る確率
ptable= binom.pmf(x, n=ntrial, p = phead)
print('確率分布：',end='')
print(np.round(ptable,3))

#元の確率変数の平均と標準偏差の算出
m0, v0 = binom.stats(ntrial, phead, moments='mv')
sd0 = np.sqrt(v0)
print('平均値　＝',np.round(m0, 3))
print('標準偏差＝',np.round(sd0, 3),'\n') 

#元の確率分布（二項分布）のグラフ描画
fig = plt.figure()
ax = fig.add_subplot(2, 2, 1)
ax.set_title('binomial distribution') 
ax.set_ylim(0, 0.5)
ax.bar(x, ptable)

#標準化された確率変数の算出
z = (x - m0) / sd0

#標準化された確率変数の表示
print('標準化された確率変数とその分布')
print('確率変数Z：',end='') 
print(np.round(z, 2))
print('確率分布 ：',end='') 
print(np.round(ptable,3))

#平均と標準偏差の算出
mz = np.dot(z, ptable) 
sdz = np.sqrt(np.dot(z*z, ptable) - mz*mz)
print('平均値　＝', end='')
print(np.round(mz, 3))
print('標準偏差＝', end='')
print(np.round(sdz, 3),'\n')

#標準化された確率分布のグラフ
ax = fig.add_subplot(2, 2, 2)
ax.set_title('stadardized distribution') 
ax.set_ylim(0, 0.5) 
ax.bar(z, ptable,width=0.5)

#表示する
plt.show()

