#サイコロによる二項分布のシミュレーション
print('【二項分布のシミュレーション】') 
#準備
import numpy as np 
from scipy.stats import randint,binom
import matplotlib.pyplot as plt

#シミュレーションの準備
ss=10      #サンプルの要素数（sample size）
ne=1000    #試行回数の設定

#サイコロをss回振る試行をne回行う
trials=randint.rvs(1, 7, size=(ne, ss))

#各試行で出た「目1」の個数を記録
n1 = np.array(
    [np.count_nonzero(trials[i] == 1) for i in range(ne)])

#「目1」がx回出たときの試行数を集計
nfreq=np.array(
     [np.count_nonzero(n1==x) for x in range(0,ss + 1)])
nfreq[0] = ne - np.sum(nfreq[1:])  #目1が出ない試行数

#相対度数を計算
rnfreq=nfreq/ne

#描画の準備
fig = plt.figure()
ax = fig.add_subplot(1, 1, 1)

#相対度数分布を棒グラフで描画
ax.set_title('binomial distribution') 
ax.set_ylim(0, 0.5)
location = np.arange(ss+1) 
ax.bar(location,rnfreq, label='relative dist.')

#二項分布の確率の算出
pbinom=binom.pmf(range(ss+1),n=ss, p=1/6)

#二項分布を折れ線で描画
ax.plot(location, pbinom, label='binomial',color='r')

# 表示する
ax.legend()
plt.show()
