#中心極限定理のシミュレーション
print('【中心極限定理の確認】')
#準備
import numpy as np
from scipy.stats import randint, norm
import matplotlib.pyplot as plt

#母平均と母分散の求める
(mu, varp) = (7/2, 35/12)
sigma = np.sqrt(varp)
print('母平均＝', np.round(mu, 3))
print('母分散＝', np.round(35/12, 3),'\n') 

#シミュレーションの設定
ss=8       #標本の大きさの設定
ne=10000   #集める標本の個数

#標本抽出のシミュレーションの実際
samples = randint.rvs(1, 7, size=(ne,ss))

#各標本について標本平均mを算出
m=np.array(
    [np.mean(samples[i]) for i in range(ne)])

#得られた標本平均についてその平均m1と分散v1を算出
m1 = np.mean(m) 
v1 = np.var(m)
print('標本平均の平均＝', np.round(m1, 3))
print('標本平均の分散＝', np.round(v1, 3))
print('（注）母分散／標本の大きさ＝', end='')
print(np.round(varp/ss, 3))

#標本平均の相対度数算出
nbin = 20      #棒グラフの棒数
hist, edges = np.histogram(m, range=(1,6), bins=nbin, density=True)

#Matplotlibで描画準備
fig = plt.figure()
ax = fig.add_subplot(1, 1, 1) 

#相対度数を棒グラフで描画
ax.set_ylim(0, 1.2)
ax.bar(edges[:-1],hist,color='c', label='samples')

#正規分布のグラフ
s1 = sigma/np.sqrt(ss)
x = np.linspace(1, 6, 101)  #区間[1, 6]を100等分
y = norm.pdf(x, loc=mu, scale=s1)
ax.plot(x, y, color='k', label='normal dist')

#グラフの表示実行
ax.legend()
plt.show()
